import {
  Button,
  Col,
  Collapse,
  Drawer,
  Form,
  Input,
  Row,
  Segmented,
  Select,
  Space,
  Table,
  Tabs,
  Typography,
} from "antd";
import { useTranslation } from "react-i18next";
import { useParams } from "react-router-dom";
import { AppStyle, Constants } from "../../utils";
import { useEffect, useState } from "react";
import { PlusOutlined } from "@ant-design/icons";
import { t } from "i18next";

export default function Crm() {
  const { t } = useTranslation();
  const { paramType } = useParams();
  const [isDrawerOpen, setIsDrawerOpen] = useState(false);

  const title =
    paramType === Constants.CRM_TYPE.CUSTOMERS
      ? "crm.customers.pageTitle"
      : paramType === Constants.CRM_TYPE.DMC_PIPELINE
      ? "crm.dmcPipeline.pageTitle"
      : "crm.setterCloser.pageTitle";

  const segmentedOptions = t(
    paramType === Constants.CRM_TYPE.DMC_PIPELINE
      ? "crm.dmcPipeline.segmentedOptions"
      : "crm.setterCloser.segmentedOptions",
    {
      returnObjects: true,
    }
  );

  const [selectedSegmentedValue, setSelectedSegmentedValue] = useState(
    segmentedOptions[0]
  );

  const getTableContent = () => {
    return [
      {
        title: t("crm.table.firstName"),
        dataIndex: "firstName",
        key: "firstName",
      },
      {
        title: t("crm.table.lastName"),
        dataIndex: "lastName",
        key: "lastName",
      },
      {
        title: t("crm.table.createdAt"),

        dataIndex: "createdAt",
        key: "createdAt",
      },
      {
        title: t("crm.table.telephone"),
        dataIndex: "telephone",
        key: "telephone",
      },
      {
        title: t("crm.table.email"),
        dataIndex: "email",
        key: "email",
      },
      {
        title: t("crm.table.lastContact"),
        dataIndex: "lastContact",
        key: "lastContact",
      },
      {
        title: t("crm.table.createdBy"),
        dataIndex: "createdBy",
        key: "createdBy",
      },
      {
        title: t("crm.table.notes"),
        dataIndex: "notes",
        key: "notes",
      },
    ];
  };

  const getTableItems = () => {
    return [
      {
        key: "1",
        id: "",
        firstName: "Max",
      },
      {
        key: "2",
        id: "",
        firstName: "Peter",
      },
      {
        key: "3",
        id: "",
        firstName: "Anna",
      },
    ];
  };

  useEffect(() => {
    if (paramType === Constants.CRM_TYPE.CUSTOMERS) return;

    setSelectedSegmentedValue(segmentedOptions[0]);
  }, [paramType]);

  return (
    <>
      <div
        style={{
          display: "flex",
          justifyContent: "space-between",
        }}
      >
        <Typography.Title level={4}>{t(title)}</Typography.Title>

        <Button icon={<PlusOutlined />} onClick={() => console.log("add")}>
          New
        </Button>
      </div>

      {paramType !== Constants.CRM_TYPE.CUSTOMERS && (
        <Segmented
          value={selectedSegmentedValue}
          onChange={(value) => setSelectedSegmentedValue(value)}
          options={segmentedOptions}
          style={{ marginBottom: AppStyle.app.margin }}
        />
      )}

      <Table
        scroll={{ x: "max-content" }}
        columns={getTableContent()}
        dataSource={getTableItems()}
        onRow={(record, rowIndex) => {
          return {
            onClick: (event) => {
              console.log("row", record, rowIndex);
              setIsDrawerOpen(true);
            },
          };
        }}
      />

      <CustomerDrawer
        isOpen={isDrawerOpen}
        onClose={() => setIsDrawerOpen(false)}
      />
    </>
  );
}

function CustomerDrawer({ isOpen, onClose }) {
  const { t } = useTranslation();

  const tabItems = [
    {
      key: "0",
      label: t("crm.tabs.dealInfo"),
      children: <TabContentDealInfo />,
    },
    {
      key: "1",
      label: t("crm.tabs.activities"),
      children: "Tab 2 content",
    },
    {
      key: "2",
      label: t("crm.tabs.notes"),
      children: "Tab 3 content",
    },
  ];

  return (
    <Drawer
      title={"loading..."}
      placement="right"
      open={isOpen}
      onClose={onClose}
      width={720}
    >
      <Tabs defaultActiveKey="0" items={tabItems} centered />
    </Drawer>
  );
}

function Content({ children }) {
  return (
    <Form layout="vertical">
      <Row gutter={16}>
        <Col xs={24} sm={12}>
          {children[0]}
        </Col>
        <Col xs={24} sm={12}>
          {children[1]}
        </Col>
      </Row>
    </Form>
  );
}

function CollapseContainer({ children, label }) {
  return (
    <Collapse
      defaultActiveKey="1"
      items={[
        {
          key: "1",
          label: label,
          children: children,
        },
      ]}
    />
  );
}

function TabContentDealInfo() {
  const [selectedPipeline, setSelectedPipeline] = useState(0);
  const [selectedDealPhase, setSelectedDealPhase] = useState(0);

  return (
    <Space direction="vertical" style={{ display: "flex" }}>
      <CollapseContainer
        label={t("crm.tabContent.dealInfo.collapseDealStatus.label")}
      >
        <Content>
          <Form.Item
            label={t("crm.tabContent.dealInfo.collapseDealStatus.pipeline")}
            initialValue={selectedPipeline}
          >
            <Select
              value={selectedPipeline}
              onChange={(value) => {
                setSelectedPipeline(value);
                setSelectedDealPhase(0);
              }}
              options={[
                {
                  value: 0,
                  label: t("crm.dmcPipeline.pageTitle"),
                },
                {
                  value: 1,
                  label: t("crm.setterCloser.pageTitle"),
                },
              ]}
            />
          </Form.Item>

          <Form.Item
            label={t("crm.tabContent.dealInfo.collapseDealStatus.dealPhase")}
            initialValue={selectedDealPhase}
          >
            <Select
              value={selectedDealPhase}
              onChange={(value) => setSelectedDealPhase(value)}
              options={t(
                selectedPipeline === 0
                  ? "crm.dmcPipeline.segmentedOptions"
                  : "crm.setterCloser.segmentedOptions",
                { returnObjects: true }
              ).map((item, index) => {
                return {
                  value: index,
                  label: item,
                };
              })}
            />
          </Form.Item>
        </Content>
      </CollapseContainer>

      <CollapseContainer
        label={t(
          t("crm.tabContent.dealInfo.collapseMasterDataOfContact.label")
        )}
      >
        <Content>
          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseMasterDataOfContact.firstName"
            )}
          >
            <Input />
          </Form.Item>

          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseMasterDataOfContact.lastName"
            )}
          >
            <Input />
          </Form.Item>
        </Content>

        <Content>
          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseMasterDataOfContact.telephone"
            )}
          >
            <Input />
          </Form.Item>

          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseMasterDataOfContact.email"
            )}
          >
            <Input />
          </Form.Item>
        </Content>

        <Content>
          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseMasterDataOfContact.company"
            )}
          >
            <Input />
          </Form.Item>

          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseMasterDataOfContact.zipCode"
            )}
          >
            <Input />
          </Form.Item>
        </Content>

        <Content>
          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseMasterDataOfContact.address"
            )}
          >
            <Input />
          </Form.Item>

          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseMasterDataOfContact.city"
            )}
          >
            <Input />
          </Form.Item>
        </Content>

        <Content>
          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseMasterDataOfContact.country"
            )}
          >
            <Input />
          </Form.Item>

          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseMasterDataOfContact.federalState"
            )}
          >
            <Input />
          </Form.Item>
        </Content>

        <Content>
          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseMasterDataOfContact.website"
            )}
          >
            <Input />
          </Form.Item>

          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseMasterDataOfContact.leadOrigin"
            )}
          >
            <Input />
          </Form.Item>
        </Content>
      </CollapseContainer>

      <CollapseContainer
        label={t(t("crm.tabContent.dealInfo.collapseSetterInfo.label"))}
      >
        <Content>
          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseSetterInfo.numberOfEmployees"
            )}
          >
            <Input />
          </Form.Item>

          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseSetterInfo.numberOfJobsSearchedFor"
            )}
          >
            <Input />
          </Form.Item>
        </Content>

        <Content>
          <Form.Item
            label={t("crm.tabContent.dealInfo.collapseSetterInfo.jobTitle")}
          >
            <Input />
          </Form.Item>

          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseSetterInfo.numberOfEmployeesRequired"
            )}
          >
            <Input />
          </Form.Item>
        </Content>

        <Content>
          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseSetterInfo.howLongHadHeBeenSearching"
            )}
          >
            <Input />
          </Form.Item>

          <Form.Item
            label={t("crm.tabContent.dealInfo.collapseSetterInfo.turnover")}
          >
            <Input />
          </Form.Item>
        </Content>
      </CollapseContainer>

      <CollapseContainer
        label={t(t("crm.tabContent.dealInfo.collapseDealProperties.label"))}
      >
        <Content>
          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseDealProperties.dateOfcompletion"
            )}
          >
            <Input />
          </Form.Item>

          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseDealProperties.orderVolume"
            )}
          >
            <Input />
          </Form.Item>
        </Content>

        <Content>
          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseDealProperties.numberOfInstallments"
            )}
          >
            <Input />
          </Form.Item>

          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseDealProperties.amountsOfTheInstallments"
            )}
          >
            <Input />
          </Form.Item>
        </Content>

        <Content>
          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseDealProperties.bookedPackages"
            )}
          >
            <Input />
          </Form.Item>

          <Form.Item
            label={t(
              "crm.tabContent.dealInfo.collapseDealProperties.assignedEmployee"
            )}
          >
            <Input />
          </Form.Item>
        </Content>
      </CollapseContainer>
    </Space>
  );
}
